@@ -59,6 +59,12 @@ namespace zypp
 //////////////////////////////////////////////////////////////////
 namespace
 {
+  namespace env
+  {
+    inline bool NO_COLOR()
+    { return ::getenv("NO_COLOR"); }
+  } // namespace env
+
   /** Simple check whether stdout is a (not dumb) tty */
   inline bool mayUseANSIEscapes()
   {
@@ -66,14 +72,14 @@ namespace
     {
       char *term = ::getenv("TERM");
       if ( term && ::strcmp( term, "dumb" ) )
-	return true;
+        return true;
     }
     return false;
   }
 
   /** Simple check whether stdout can handle colors */
   inline bool hasANSIColor()
-  { return mayUseANSIEscapes(); }
+  { return mayUseANSIEscapes() && not env::NO_COLOR(); }
 
   /** Color names (case insensitive) accepted in the config file. */
   ansi::Color namedColor( std::string name_r )
@@ -131,19 +137,11 @@ namespace
     return ret;
   }
 
-  void setColorForOut ( const bool &set )
-  {
-    OutNormal *currOut = dynamic_cast<OutNormal *>( Zypper::instance().outputWriter() );
-    if ( currOut )
-      currOut->setUseColors( set );
-  }
+  void setColorForOut ( bool yesno_r )
+  { Zypper::instance().out().setUseColors( yesno_r ); }
 
-  void setOutVerbosity ( Out::Verbosity verb )
-  {
-    Out *currOut = Zypper::instance().outputWriter();
-    if ( currOut )
-      currOut->setVerbosity( verb );
-  }
+  void setOutVerbosity ( Out::Verbosity verb_r )
+  { Zypper::instance().out().setVerbosity( verb_r ); }
 } // namespace
 //////////////////////////////////////////////////////////////////
 
@@ -180,7 +178,9 @@ namespace
     SEARCH_RUNSEARCHPACKAGES,
 
     OBS_BASE_URL,
-    OBS_PLATFORM
+    OBS_PLATFORM,
+
+    SUBCOMMAND_SEACHSUBCOMMANDINPATH,
   };
 
   const std::vector<std::pair<std::string,ConfigOption>> & optionPairs()
@@ -215,7 +215,9 @@ namespace
       { "search/runSearchPackages",		ConfigOption::SEARCH_RUNSEARCHPACKAGES		},
 
       { "obs/baseUrl",				ConfigOption::OBS_BASE_URL			},
-      { "obs/platform",				ConfigOption::OBS_PLATFORM			}
+      { "obs/platform",				ConfigOption::OBS_PLATFORM			},
+
+      { "subcommand/seachSubcommandInPath",	ConfigOption::SUBCOMMAND_SEACHSUBCOMMANDINPATH	},
     };
     return _data;
   }
@@ -225,7 +227,7 @@ namespace
     for ( const auto & p : optionPairs() )
     {
       if ( p.second == value_r )
-	return p.first;
+        return p.first;
     }
     return std::string();
   }
@@ -415,9 +417,9 @@ std::vector<ZyppFlags::CommandGroup> Config::cliOptions()
           _("Do not abbreviate text in tables.")
           ).setDependencies( { "terse" } )
         ),
-        { "table-style", 's', ZyppFlags::RequiredArgument, ZyppFlags::GenericValueType( Table::defaultStyle ),
-              // translators: --table-style, -s
-              _("Table style (integer).")
+        { "table-style", 's', ZyppFlags::RequiredArgument, ZyppFlags::GenericValueType( Table::defaultStyle, ARG_INTEGER ),
+              // translators: --table-style, -s, %1% denotes the supported range of the integer argument (e.g. "1-11")
+              str::Format(_("Table style (%1%).") ) % ("0-"+str::numstring((int)TLS_End-1))
         },
         { "non-interactive", 'n', ZyppFlags::NoArgument, std::move( ZyppFlags::BoolType( &non_interactive, ZyppFlags::StoreTrue, non_interactive )
               .after( []( ){
@@ -727,16 +729,16 @@ void Config::read( const std::string & file )
     {
       c = namedColor( augeas.getOption( asString( el.second ) ) );
       if ( c )
-	el.first = c;
+        el.first = c;
       // Fix color attributes: Default is mapped to Unchanged to allow
       // using the ColorStreams default rather than the terminal default.
       if ( el.second == ConfigOption::COLOR_PKGLISTHIGHLIGHT_ATTRIBUTE )	// currently the only one
       {
-	ansi::Color & c( el.first );
-	if ( c.fg() == ansi::Color::Fg::Default )
-	  c.fg( ansi::Color::Fg::Unchanged );
-	if ( c.bg() == ansi::Color::Bg::Default )
-	  c.bg( ansi::Color::Bg::Unchanged );
+        ansi::Color & c( el.first );
+        if ( c.fg() == ansi::Color::Fg::Default )
+          c.fg( ansi::Color::Fg::Unchanged );
+        if ( c.bg() == ansi::Color::Bg::Default )
+          c.bg( ansi::Color::Bg::Unchanged );
       }
     }
 
@@ -744,13 +746,13 @@ void Config::read( const std::string & file )
     if (!s.empty())
     {
       if ( s == "all" )
-	color_pkglistHighlight = true;
+        color_pkglistHighlight = true;
       else if ( s == "first" )
-	color_pkglistHighlight = indeterminate;
+        color_pkglistHighlight = indeterminate;
       else if ( s == "no" )
-	color_pkglistHighlight = false;
+        color_pkglistHighlight = false;
       else
-	WAR << "zypper.conf: color/pkglistHighlight: unknown value '" << s << "'" << endl;
+        WAR << "zypper.conf: color/pkglistHighlight: unknown value '" << s << "'" << endl;
     }
 
     s = augeas.getOption("color/background");	// legacy
@@ -779,6 +781,9 @@ void Config::read( const std::string & file )
     if (!s.empty())
       obs_platform = s;
 
+    s = augeas.getOption( asString( ConfigOption::SUBCOMMAND_SEACHSUBCOMMANDINPATH ) );
+    if ( not s.empty() )
+      seach_subcommand_in_path = str::strToBool( s, seach_subcommand_in_path );
 
     // finally remember the default config file for saving back values
     _cfgSaveFile = augeas.getSaveFile();
