@@ -125,7 +125,7 @@ int ZypperBaseCommand::parseArguments( Zypper &, const int argc, char * const *a
 
   if ( _fillRawOptions ) {
     //skip first argument here as well
-    for ( int i = 1; i < argc; i++ ) {
+    for ( int i = 1; i < argc; ++i ) {
       _rawOptions.push_back( argv[ i ] );
     }
   }
@@ -193,6 +193,7 @@ int ZypperBaseCommand::defaultSystemSetup( Zypper &zypper, SetupSystemFlags flag
   if ( zypper.exitCode() != ZYPPER_EXIT_OK )
     return zypper.exitCode();
 
+#if 0 // since libzypp 17.23.0 the Resolver auto establishes the PPP status.
   if ( flags_r.testFlag ( Resolve ) ) {
     // have REPOS and TARGET
     // compute status of PPP
@@ -200,6 +201,7 @@ int ZypperBaseCommand::defaultSystemSetup( Zypper &zypper, SetupSystemFlags flag
     base::LogControl::TmpLineWriter shutUp;	// reduce logging; some day libzypp/libsolv may offer a shotcut to establish
     resolve( zypper );
   }
+#endif
 
   return zypper.exitCode();
 }
